Description Usage Arguments Value
Construct a matrix of expression summary values per cluster.
1 2 3 | clusterExprsSummaryMatrix(FGDEGtab, FGexprs, FGassign, Q = 0.5,
cellColumn = "cell_id", geneColumn = "entrez_id",
clusterColumn = "cluster_id")
|
FGDEGtab |
The raw FASTGenomics Differentially Expressed Gene table, e.g. the output from FASTGenomics calc_de_genes_nonparametric. |
FGexprs |
A sparse Matrix of expression values in cells x genes format. |
FGassign |
data.frame with cluster assignments for cells. |
Q |
Quantile used for expression value summary; defaults to 0.5, i.e. the median. |
cellColumn |
Column name for cell name; defaults to "cell_id". |
geneColumn |
Column name for gene ID; defaults to "entrez_id". |
clusterColumn |
Column name for cluster assignment; defaults to "cluster_id". |
A gene x cluster matrix of summarized cluster expression values.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.